clear all

************************************************************************************************************* This do *** This dofile uses the original files provided by the survey company, 
*** merges and cleans them, and puts them all in the same data file, 
*** which will be used for the analysis
*** Note that this file also renames the survey questions so that their names are 
*** the same as in the questionnaire 
*** (The survey firm had its own internal numbering of variables, not corresponding to the questionnaire)
**********************************************************************************************************


*** THE DESCRIPTION OF ALL DATA FILES AND THEIR CODEBOOKS ARE PROVIDED IN THE FILE: 
*** "Description and codebook of original data files"


**********************************************************************************************************
**** This part of the do-file imports the data from the source files of the main experiment and clean them
**********************************************************************************************************

* Here are the original survey data:
global survey1 "$original_data/Survey+1_May+27%2C+2019_01.02.csv"
global survey2 "$original_data/Survey+2_May+27%2C+2019_01.03.csv"
global survey3 "$original_data/Survey+3_May+27%2C+2019_01.03.csv"




forvalues i = 1/3 {
	clear all

	* SELECT THE SURVEY TO CHECK:
	global survey `i'
	import delimited "${survey`i'}", varnames(1) 



	gen n = _n
	keep if n > 4
	keep if distributionchannel != "preview"

	destring q2 q3 q4 q5 q6 q7 q8 q9_1 q10 q11 q12 q13 q14 q15 q16_* q17 ///
	q18_1 q18_2 q18_3 q18_4 q19_* q20_1 q21 q22 q27 q28 q29 ///
	q30 q34 q37 q45_nps q45 q46_* q47_1 q48 q49 q50 q84_1 q85 q52_* q86 durationinseconds gc, replace

	* Filter on the duration of the survey:
	keep if durationinseconds >= 250
	keep if gc == 1

	* Hour
	gen survey_id = `i'
	gen year = substr(startdate, 1, 4)
	gen month = "may"
	gen day = substr(startdate, 9, 2)
	gen hour = substr(startdate, 12, 2)
	destring hour day, replace
	replace hour = hour + 8
	replace day = day + 1 if hour > 23
	replace hour = hour - 24 if hour > 23
	
	tostring hour day, replace
	gen minutes = substr(startdate, 15, 2)

	
	gen date = day+month+year+" "+ hour+":"+"00"+":"+"00"

	gen time = clock(date, "DMYhms")
	
	format time %tcDDmonCCYY_HH

	destring day hour minutes durationinseconds, replace
	
	replace durationinseconds = durationinseconds/60
	
	sum durationinseconds
	replace minutes = minutes + `r(mean)'
	
	gen freq = 1
	gen fb = 0
	gen fake = 1 if q34==1
	replace fake = 0 if fake==.
 	
	gen fact = 0 
	if `i'!=1{
	destring q41, replace
	replace fact = 1 if q41==1
    }
	
	local j = `i'

		* Import the data from Google Analytics
		
					
			replace hour = hour + 1 if minutes >= 60
			replace hour = 00 if hour == 24
			replace day = day + 1 if hour == 00
			
			merge m:1 day hour survey_id fb fake using "$original_data/GA_hours.dta", keepus(fake) keep(1 3) gen(merge1)
			local j = 0

			replace hour = hour - 1 if minutes >= 60 & merge1==1
			replace day = day - 1 if hour == -1 & merge1==1		
			replace hour = 23 if hour == -1 & merge1==1

			
			
			merge m:1 day hour survey_id fb fake using "$original_data/GA_hours.dta", keepus(pageviews uniquepageviews avg_share number_share) keep(1 3)

			
			bys day hour survey_id fb: egen total_participants_fake = total(freq) if fake==1
			
			gen prob_view_fake = uniquepageviews/total_participants_fake if total_participants_fake >= uniquepageviews & fake==1
			gen prob_share_GA_fake = number_share/total_participants_fake if total_participants_fake >= number_share & fake==1
			bys survey_id fb: egen total_prob_view_fake = total(prob_view_fake) 
			bys survey_id fb: egen total_prob_share_GA_fake = total(prob_share_GA_fake)
			
			drop _merge merge1
			
			
			label var total_participants_fake "Total participants accessed Alt-Facts"
			label var prob_view_fake "Probability actual share Alt-Facts"
			label var prob_share_GA_fake "Probability actual re-share Alt-Facts"
			
			*** do same thing for facts
			merge m:1 day hour survey_id fb fact using "$original_data/GA_hours.dta", keepus(pageviews uniquepageviews avg_share number_share) keep(1 3)

			
			bys day hour survey_id fb: egen total_participants_fact = total(freq) if fact==1
			
			gen prob_view_fact = uniquepageviews/total_participants_fact if total_participants_fact >= uniquepageviews & fact==1
			gen prob_share_GA_fact = number_share/total_participants_fact if total_participants_fact >= number_share & fact==1
			bys survey_id fb: egen total_prob_view_fact = total(prob_view_fact) 
			bys survey_id fb: egen total_prob_share_GA_fact = total(prob_share_GA_fact)
			
			drop _merge  

	* Import the data from Facebook
	cap gen fact = 0
	replace hour = hour + 1 if minutes >= 60
	replace hour = 00 if hour == 24
	replace day = day + 1 if hour == 00
	merge m:1 day hour survey_id fake fact using "$original_data/share_facebook.dta", keep(1 3) gen(merge1)

	
	replace hour = hour - 1 if minutes >= 60 & merge1==1
	replace hour = 23 if hour == -1 & merge1==1
	replace day = day - 1 if hour == 23 & merge1==1	
	
	drop number_share_fb
	merge m:1 day hour survey_id fake fact using "$original_data/share_facebook.dta", keep(1 3)
	
	* this number of share on facebook can include reshares so it is not  probability
	gen rate_share_fb_fake = number_share_fb/total_participants_fake
	cap gen rate_share_fb_fact = number_share_fb/total_participants_fact
	
	

	drop _m
	
	* Labelling :
	lab var q1 "Take survey"
	lab var q89 "Social Network"
	lab var q2 "Age"
	lab var q3 "City size"
	lab var q4 "Education"
	lab define educ 1 "No diploma" 2 "Certificat d'Etude Primaire" 3 "Ancien Brevet, B.E.P.C." 4 "CAP" ///
	 5 "BEP" 6 "BAC pro" 7 "BAC general" ///
	 8 "BAC + 2" 9 "Diplome superieur"
	lab value q4 educ
	
	gen no_educ = 1 if q4==1
	replace no_educ = 0 if no_educ ==.
	lab var no_educ "No Education"
	gen educ_CEP = 1 if q4==2
	replace educ_CEP = 0 if educ_CEP==.
	lab var educ_CEP "Certificat d'Etude Primaire"
	gen educ_BEPC = 1 if q4==3
	replace educ_BEPC = 0 if educ_BEPC==.
	lab var educ_BEPC "Ancien Brevet, B.E.P.C."
	gen educ_CAP = 1 if q4==4
	replace educ_CAP = 0 if educ_CAP==.
	lab var educ_CAP "CAP"
	gen educ_BEP = 1 if q4==5
	replace educ_BEP = 0 if educ_BEP==.
	lab var educ_BEP "BEP"
	gen educ_BACpro = 1 if q4==6
	replace educ_BACpro = 0 if educ_BACpro == .
	lab var educ_BACpro "BAC pro"
	gen educ_BAC = 1 if q4==7
	replace educ_BAC = 0 if educ_BAC==.
	lab var educ_BAC "BAC"
	gen educ_BAC2 = 1 if q4==8
	replace educ_BAC2 = 0 if educ_BAC2==.
	lab var educ_BAC2 "BAC + 2"
	gen educ_sup = 1 if q4==9
	replace educ_sup = 0 if educ_sup==.
	lab var educ_sup "Diplome Superieur"
	
	* This is for the enforced quota constraint (should be 72%):
	gen low_educ = 1 if q4 <= 7
	replace low_edu = 0 if low_educ==.
	lab var low_educ "Low Education"
	
	
	lab var q5 "Sex"
	lab define sex 1 "Male" 2 "Female"
	lab val q5 sex
	lab var q6 "Place of birth"
	lab var q7 "Place birth father"
	lab var q8 "Place birth mother"
	lab var q9 "Region"
	lab var q10 "Matrimonial Status"
	lab var q11 "Income"
	lab var q12 "Child"
	lab var q13 "Usage FB"
	lab var q14 "Number of Facebook Friends"
	lab var q15 "Frequency Sharing on Facebook"
	* Reasons to share
	lab var q16_1 "Interesting post"
	lab var q16_2 "Influence"
	lab var q16_3 "Good image"
	lab var q16_4 "Reciprocity"
	lab var q17 "Media type"
	lab var q17_7_text "Media type: other"
	* Altruism
	lab var q18_1 "Money to Charity"
	lab var q18_2 "Homeless"
	lab var q18_3 "Work for Charity"
	lab var q18_4 "Blood donor"
	* Help
	lab var q19_1 "Give it back"
	lab var q19_2 "Out of Confort Zone"
	lab var q19_3 "Personal Cost"
	lab var q20 "Importancy of selfishness"
	lab var q21 "Religion"
	lab var q22 "Frequency religious place"
	lab var q27 "Level of collectivity"
	lab var q28 "Inscription Liste"

	lab var q86 "Image UE"

	lab var q29 "Vote Premier Tour"
	lab define premtour 1 "Fillon" 2 "MLP" 3 "Macron" 4 "Mélencon" 5 "Other" 6 "Not voted" 7 "Prefer not to answer this question"
	lab val q29 premtour 

	
	
	gen first_fillon = 1 if q29 == 1
	replace first_fillon = 0 if first_fillon==.
	lab var first_fillon "Premier Tour Fillon"
	gen first_mlp = 1 if q29 == 2
	replace first_mlp = 0 if first_mlp==.
	lab var first_mlp "Premier Tour Le Pen"
	gen first_macron = 1 if q29 == 3
	replace first_macron = 0 if first_macron==.
	lab var first_macron "Premier Tour Macron"
	gen first_melenchon = 1 if q29 == 4
	replace first_melenchon = 0 if first_melenchon==.
	lab var first_melenchon "Premier Tour Mélenchon"
	gen first_autre = 1 if q29 == 5
	replace first_autre = 0 if first_autre==.
	lab var first_autre "Premier Tour Autre Candidat"
	gen first_no = 1 if q29 == 6
	replace first_no = 0 if first_no==.
	lab var first_no "Premier Tour Pas Voté"
	
	gen vote_premier = first_fillon + first_mlp + first_macron + first_melenchon + first_autre + first_no
	global candidats first_fillon first_mlp first_macron first_melenchon first_autre first_no
	foreach z in $candidats {
	replace `z' = . if vote_premier == 0
}
	lab var vote_premier "Vote Premier Tour"
	lab var q30 "Vote Second Tour"
	lab define sectour 1 "MLP" 2 "Macron" 3 "Not voted" 4 "Prefer not to answer this question"
	lab val q30 sectour

	gen second_mlp = 1 if q30 == 1
	replace second_mlp = 0 if second_mlp==.
	lab var second_mlp "Second Tour Le Pen"
	gen second_macron = 1 if q30 == 2
	replace second_macron = 0 if second_macron==.
	lab var second_macron "Second Tour Macron"

	gen married = 1 if q10 == 2
	replace married = 0 if married == .
	lab var married "Married"

	lab var q34 "Share Fake News on Facebook"
	lab var q37 "Share Fake News with 100 others"
	if `i' == 2 {
	lab var q41 "Share Fact Check on Facebook"  
	}
	if `i' == 3 {
	lab var q38 "See Fact Check"
	lab var q41 "Share Fact Check on Facebook"
	}
	lab var q45 "Political orientation (Left-Right)"
	lab var q46_1 "Intention to vote: LFI"
	lab var q46_2 "Intention to vote: LREM"
	lab var q46_3 "Intention to vote: RN"
	lab var q46_4 "Intention to vote: UMP"
	lab var q46_5 "Intention to vote: EE"
	lab var q46_6 "Intention to vote: GJ"

	lab var q47 "Want Frexit"
	lab var q48 "Think Frexit Beneficial"
	lab var q49 "Worried by boarder control due to EU"
	lab var q50 "Brexit: Who has the most to loose"
	lab var q87 "Two most important issues for EU"
	
	gen q87_1 = substr(q87,1,1)
	gen q87_2 = substr(q87,3,1)
	
	destring q87_*, replace
	
	lab var q87_1 "Two most important issues for EU 1"
	lab var q87_2 "Two most important issues for EU 2"
	
	lab var q51 "Two most important fields for EU elections"
	
	gen q51_1 = substr(q51,1,1)
	gen q51_2 = substr(q51,3,1)
	
	destring q51_*, replace
	
	lab var q51_1 "Two most important fields for EU elections 1"
	lab var q51_2 "Two most important fields for EU elections 2"
	
	lab var q52_1 "Media Trust: National Newpaper"
	lab var q52_2 "Media Trust: Local Newspaper"
	lab var q52_3 "Media Trust: Online Newspaper"
	lab var q52_4 "Media Trust: Fact Checking Websites"
	lab var q52_5 "Media Trust: TV"
	lab var q52_6 "Media Trust: OECD"
	lab var q52_7 "Media Trust: Eurostat"
	lab var q84_1 "Gain Participation EU"
	lab var q85 "Share National Laws from EU"


	gen mlp_second=second_mlp
	gen macron_second= second_macron
	gen vote_second = second_mlp+second_macron
	lab var mlp_second "Second Tour Le Pen"
	lab var macron_second "Second Tour Macron"
	lab var vote_second "Vote Second Tour"

	replace mlp_second=. if vote_second==0
	replace macron_second=. if vote_second==0

	gen facebook_friends=q14
	replace facebook_friends=. if facebook_friends>5000
	lab var facebook_friends "Number of FB Friends below 5000"

	save "$generated_data/survey${survey}.dta", replace
	
	count if q34==1
	count if prob_view_fake !=. & survey_id== `i'
	cap count if prob_view_fact !=. & survey_id== `i'
	count if rate_share_fb_fake !=. & survey_id== `i'
	cap count if rate_share_fb_fact !=. & survey_id== `i'
}



**********************************************************************************************************
*** This part of the do file imports the data from the follow-up experiment and cleans it.
**********************************************************************************************************


* Indicate the last version of the survey data:global wave2 
global wave2 "$original_data/Survey+4%2C+5+and+6+-+RANDOMIZED_May+27%2C+2019_01.04.csv"


clear all
* SELECT THE SURVEY TO CHECK:

import delimited "$wave2", varnames(1) 


gen n = _n
keep if n > 4
keep if distributionchannel != "preview"

	destring q3 q4 q5 q6 q7 q8 q9_1 q10 q11 q12 q13 q14 q15 q16_* q17 ///
	q18_1 q18_2 q18_3 q18_4 q19_* q20_1 q21 q22 q27 q28 q29 ///
	q30 q34 q45_nps q45 q46_* q47_1 q48 q49 q50 q84_1 q85 q52_* q86 q88 q97 durationinseconds gc group, replace

* Filter on the duration of the survey:
keep if durationinseconds > 250

* Hour

	gen survey_id = 5 if group == 1
	replace survey_id = 6 if group == 2
	replace survey_id = 4 if group == 3
	gen year = substr(startdate, 1, 4)
	gen month = "may"
	gen day = substr(startdate, 9, 2)
	gen hour = substr(startdate, 12, 2)
	destring hour day, replace
	replace hour = hour + 8
	replace day = day + 1 if hour > 23
	replace hour = hour - 24 if hour > 23
	
	tostring hour day, replace
	gen minutes = substr(startdate, 15, 2)

	gen date = day+month+year+" "+ hour+":"+"00"+":"+"00"

	gen time = clock(date, "DMYhms")

	format time %tcDDmonCCYY_HH
	
	destring day hour minutes durationinseconds, replace
	
	replace durationinseconds = durationinseconds/60
	
	sum durationinseconds
	replace minutes = minutes + `r(mean)'
	
	gen freq = 1
	gen fb = 0
	gen fake = 1 if q34==1 | q97==1
	lab var fake "Want to Share Fake News"
	replace fake = 0 if fake==.


	
	* Import the data from Google Analytics
	
		replace hour = hour + 1 if minutes >= 60
	replace hour = 00 if hour == 24
	replace day = day + 1 if hour == 00
			merge m:1 day hour survey_id fb fake using "$original_data/GA_hours.dta", keepus(fake) keep(1 3) gen(merge1)
			
						replace hour = hour - 1 if minutes >= 60 & merge1==1
			replace hour = 23 if hour == -1 & merge1==1
			replace day = day - 1 if hour == 23 & merge1==1	

			
			merge m:1 day hour survey_id fb fake using "$original_data/GA_hours.dta", keepus(pageviews uniquepageviews avg_share number_share) keep(1 3)

			
			bys day hour survey_id fb fake: egen total_participants_fake = total(freq) if fake==1
			
			gen prob_view_fake = uniquepageviews/total_participants_fake if total_participants_fake >= uniquepageviews & fake==1
			gen prob_share_GA_fake = number_share/total_participants_fake if total_participants_fake >= number_share  & fake==1
			bys survey_id fb: egen total_prob_view_fake = total(prob_view_fake)
			bys survey_id fb: egen total_prob_share_GA_fake = total(prob_share_GA_fake)
			drop fb _m
			

			
			* Import the data from Facebook:
			gen fact = 0
				replace hour = hour + 1 if minutes >= 60
	        replace hour = 00 if hour == 24
	        replace day = day + 1 if hour == 00
			
			merge m:1 day hour survey_id fake fact using "$original_data/share_facebook.dta", keep(1 3)
	
						replace hour = hour - 1 if minutes >= 60 & merge1==1
			replace hour = 23 if hour == -1 & merge1==1
			replace day = day - 1 if hour == 23 & merge1==1	
			drop number_share_fb _m
			
			merge m:1 day hour survey_id fake fact using "$original_data/share_facebook.dta", keep(1 3)
			
		* this number of share on facebook can include reshares so it is not  probability
			gen rate_share_fb_fake = number_share_fb/total_participants_fake  & fake==1
			
* Labelling :
lab var q1 "Take survey"
lab var q89 "Social Network"
lab var q88 "Age"
lab var q3 "City size"
lab var q4 "Education"
lab define educ 1 "No diploma" 2 "Certificat d'Etude Primaire" 3 "Ancien Brevet, B.E.P.C." 4 "CAP" ///
 5 "BEP" 6 "BAC pro" 7 "BAC general" ///
 8 "BAC + 2" 9 "Diplome superieur"
lab value q4 educ

gen no_educ = 1 if q4==1
replace no_educ = 0 if no_educ ==.
lab var no_educ "No Education"
gen educ_CEP = 1 if q4==2
replace educ_CEP = 0 if educ_CEP==.
lab var educ_CEP "Certificat d'Etude Primaire"
gen educ_BEPC = 1 if q4==3
replace educ_BEPC = 0 if educ_BEPC==.
lab var educ_BEPC "Ancien Brevet, B.E.P.C."
gen educ_CAP = 1 if q4==4
replace educ_CAP = 0 if educ_CAP==.
lab var educ_CAP "CAP"
gen educ_BEP = 1 if q4==5
replace educ_BEP = 0 if educ_BEP==.
lab var educ_BEP "BEP"
gen educ_BACpro = 1 if q4==6
replace educ_BACpro = 0 if educ_BACpro == .
lab var educ_BACpro "BAC pro"
gen educ_BAC = 1 if q4==7
replace educ_BAC = 0 if educ_BAC==.
lab var educ_BAC "BAC"
gen educ_BAC2 = 1 if q4==8
replace educ_BAC2 = 0 if educ_BAC2==.
lab var educ_BAC2 "BAC + 2"
gen educ_sup = 1 if q4==9
replace educ_sup = 0 if educ_sup==.
lab var educ_sup "Diplome Superieur"

	* This is for the enforced quota constraint (should be 72%):
	gen low_educ = 1 if q4 <= 7
	replace low_edu = 0 if low_educ==.
	lab var low_educ "Low Education"

	lab var q5 "Sex"
	lab define sex 1 "Male" 2 "Female"
	lab val q5 sex
	lab var q6 "Place of birth"
	lab var q7 "Place birth father"
	lab var q8 "Place birth mother"
	lab var q9_1 "Region"
	lab var q10 "Matrimonial Status"
	lab var q11 "Income"
	lab var q12 "Child"
	lab var q13 "Usage FB"
	lab var q14 "Number of Facebook Friends"
	lab var q15 "Frequency Sharing on Facebook"
	* Reasons to share
	lab var q16_1 "Interesting post"
	lab var q16_2 "Influence"
	lab var q16_3 "Good image"
	lab var q16_4 "Reciprocity"
	lab var q17 "Media type"
	lab var q17_7_text "Media type: other"
	* Altruism
	lab var q18_1 "Money to Charity"
	lab var q18_2 "Homeless"
	lab var q18_3 "Work for Charity"
	lab var q18_4 "Blood donor"
	* Help
	lab var q19_1 "Give it back"
	lab var q19_2 "Out of Confort Zone"
	lab var q19_3 "Personal Cost"
	lab var q20 "Importancy of selfishness"
	lab var q21 "Religion"
	lab var q22 "Frequency religious place"
	lab var q27 "Level of collectivity"
	lab var q28 "Inscription Liste"

lab var q86 "Image UE"

lab var q29 "Vote Premier Tour"
lab define premtour 1 "Fillon" 2 "MLP" 3 "Macron" 4 "Mélencon" 5 "Autre" 6 "Pas voté"
lab val q29 premtour 

gen first_fillon = 1 if q29 == 1
replace first_fillon = 0 if q29 != 1
lab var first_fillon "Premier Tour Fillon"
gen first_mlp = 1 if q29 == 2
replace first_mlp = 0 if q29 != 2
lab var first_mlp "Premier Tour Le Pen"
gen first_macron = 1 if q29 == 3
replace first_macron = 0 if q29 != 3
lab var first_macron "Premier Tour Macron"
gen first_melenchon = 1 if q29 == 4
replace first_melenchon = 0 if q29 != 4
lab var first_melenchon "Premier Tour Mélenchon"
gen first_autre = 1 if q29 == 5
replace first_autre = 0 if q29 != 5
lab var first_autre "Premier Tour Autre Candidat"
gen first_no = 1 if q29 == 6
replace first_no = 0 if q29 != 6
lab var first_no "Premier Tour Pas Voté"

	gen vote_premier = first_fillon + first_mlp + first_macron + first_melenchon + first_autre + first_no
	global candidats first_fillon first_mlp first_macron first_melenchon first_autre first_no
	foreach z in $candidats {
	replace `z' = . if vote_premier == 0
}
	lab var vote_premier "Vote Premier Tour"

lab var q30 "Vote Second Tour"
lab define sectour 1 "MLP" 2 "Macron" 3 "Pas voté"
lab val q30 sectour

gen second_mlp = 1 if q30 == 1
replace second_mlp = 0 if q30 != 1
lab var second_mlp "Second Tour Le Pen"
gen second_macron = 1 if q30 == 2
replace second_macron = 0 if q30 != 2
lab var second_macron "Second Tour Macron"

gen married = 1 if q10 == 2
replace married = 0 if married == .
lab var married "Married"

lab var q34 "Share Fake News on Facebook T1"
lab var q97 "Share Fake News on Facebook T2"

lab var q45 "Political orientation (Left-Right)"
lab var q46_1 "Intention to vote: LFI"
lab var q46_2 "Intention to vote: LREM"
lab var q46_3 "Intention to vote: RN"
lab var q46_4 "Intention to vote: UMP"
lab var q46_5 "Intention to vote: EE"
lab var q46_6 "Intention to vote: GJ"

lab var q47 "Want Frexit"
lab var q48 "Think Frexit Beneficial"
lab var q49 "Worried by boarder control due to EU"
lab var q50 "Brexit: Who has the most to loose"
lab var q87 "Two most important issues for EU"
lab var q51 "Two most important fields for EU elections"
lab var q52_1 "Media Trust: National Newpaper"
lab var q52_2 "Media Trust: Local Newspaper"
lab var q52_3 "Media Trust: Online Newspaper"
lab var q52_4 "Media Trust: Fact Checking Websites"
lab var q52_5 "Media Trust: TV"
lab var q52_6 "Media Trust: OECD"
lab var q52_7 "Media Trust: Eurostat"
lab var q84_1 "Gain Participation EU"
lab var q85 "Share National Laws from EU"

gen mlp_second=second_mlp
gen macron_second= second_macron
gen vote_second = second_mlp+second_macron
lab var mlp_second "Second Tour Le Pen"
lab var macron_second "Second Tour Macron"
lab var vote_second "Vote Second Tour"

replace mlp_second=. if vote_second==0
replace macron_second=. if vote_second==0

gen facebook_friends=q14
replace facebook_friends=. if facebook_friends>5000
lab var facebook_friends "Number of FB Friends below 5000"

order time group q1 q4 no_educ educ_CEP educ_BEPC educ_CAP educ_BEP educ_BACpro educ_BAC ///
q9_1 q10 q11 q12 q13 q14 q15 q16_1 q16_2 q16_3 q16_4 q17 q17_7_text q18_1 ///
 q18_2 q18_3 q18_4 q19_1 q19_2 q19_3 q20_1 q21 q22 q27 q28 q29 q3 q30 q34 q4 q45 ///
 q45_nps_group q46_1 q46_2 q46_3 q46_4 q46_5 q46_6 q47_1 q48 q49 q5 q50 q51 q52_1 ///
 q52_2 q52_3 q52_4 q52_5 q52_6 q52_7 q6 q7 q8 q84_1 q85 q86 q87 q88 q89 q97 ///
  married vote_second mlp_second macron_second second_macron second_mlp first_autre first_fillon first_macron first_melenchon ///
 first_mlp first_no facebook_friends fake survey_id prob_view prob_share_GA rate_share_fb total_participants uniquepageviews pageviews number_share avg_share 


save "$generated_data/wave2.dta", replace


* Now we append all the dta:
use "$generated_data/survey1.dta", clear


gen survey = 1

append using "$generated_data/survey2.dta"

replace survey = 2 if survey == .


append using "$generated_data/survey3.dta"

replace survey = 3 if survey == .

gen wave2 = 1

append using "$generated_data/wave2.dta"

drop wave
gen wave = wave2
drop wave2
replace wave = 2 if wave==.
replace survey=4 if group==3
replace survey=5 if group==1
replace survey=6 if group==2

replace q2 = q88 if survey>3

gen share_fb = 100 if q34==1 | q97==1
replace share_fb = 0 if share_fb==.

gen share_others = 100 if q37==1
replace share_others=0 if share_others==.

gen male = 1 if q5==1
replace male = 0 if q5==2
lab var male "Male"

rename q2 age

gen age_sqr = age^2
lab var age_sqr "Age$^{2}$"

gen income = q11 if q11 < 11
lab var income "Income (1-10)"

lab var survey "Survey Number"
lab var share_fb "Share on FB"
lab var share_others "Share with Participants"
lab var facebook_friends "Facebook Friends"
lab var first_mlp "First Round Le Pen"
lab var second_mlp "Second Round Le Pen"

gen negative_image_UE = q86 
lab var negative_image_UE "Negative Image UE (1-5)"


gen survey2 = 1 if survey == 2
replace survey2 = 0 if survey == 1 | survey == 3
lab var survey2 "2"

gen survey3 = 1 if survey == 3
replace survey3 = 0 if survey == 1 | survey == 2
lab var survey3 "3"

gen survey5 = 1 if survey == 5
replace survey5 = 0 if survey == 6
lab var survey5 "5"

gen survey6 = 1 if survey == 6
replace survey6 = 0 if survey == 5
lab var survey6 "6"

lab var share_fb "Desire share Fake News on Fb"

* index Altruism
pca q18_1 q18_2 q18_3 q18_4

predict pc1, score
rename pc1 index_altruism
lab var index_altruism "Index Altruism"

* Index Help
pca q19*
predict pc1, score
rename pc1 index_help
lab var index_help "Index Help Others"

save "$generated_data/surveys.dta", replace

* check if the merges were correct :
bys survey_id: sum  total_prob_view_fake total_prob_share_GA_fake


use "$original_data/GA_hours.dta", clear
bys fake fb survey_id: egen total_unique_views = total(uniquepageviews)
bys fake fb survey_id: egen total_shares = total(number_share)
sort survey_id fake fb


**** rename the question numbers, to match the ORDER in which they were asked in the actual survey

clear
use "$generated_data/surveys.dta"

rename q1 q0
label var q0 "Informed consent"
rename q89 q1 
rename q88 q2
rename q9_1 q9
label var q9 "Region of current residence"

label var q19_2 "Out of comfort zone"

rename q20_1 q20
label var q20 "Importance of not being considered selfish"

label var q22 "Attend religious services"

rename	q27	q23
rename	q28	q24
rename	q29	q25
rename	q30	q26
rename	q86	q27
rename  q38 q28
rename  q34 q29 
rename  q37 q30
rename  q41 q31
drop q45_nps_group
rename q45 q32

forvalues i=1/6{
	rename q46_`i' q33_`i'
}

rename q47_1 q34
rename q84_1 q35
rename q48	q36
label var q36 "European project constitute a source of hope"
rename q49	q37
rename q50	q38
rename q87	q39
rename q87_1 q39_1
rename q87_2 q39_2
rename q51	q40
rename q51_1	q40_1
rename q51_2	q40_2
rename q85	q41

forvalues i=1/7{
	rename q52_`i' q42_`i'
}

drop q17_7_texttopics

replace q29=q97 if q97!=.&q29==.

order q0 q1 q2 q3 q4 q5 q6 q7 q8 q9 q10 q11 q12 q13 q14 q15 q16_1 q16_2 q16_3 q16_4 q17 q17_7_text q18_1 q18_2 q18_3 q18_4 q19_1 q19_2 q19_3 q20 q21 q22 q23 q24 q25 q26 q27 q28 q29 q30 q31 q32 q33_1 q33_2 q33_3 q33_4 q33_5 q33_6 q34 q35 q36 q37 q38 q39 q40 q41 q42_1 q42_2 q42_3 q42_4 q42_5 q42_6 q42_7 q97

destring  q0 q1 q28  q31 q39 q40, replace
compress

drop group _merge wave rate_share_fb_fact rate_share_fb_fake number_share_fb merge1 fact fake fb freq n term gc isnew basic pid psid v rid opp



**********************************************************************************************************
*** eraze the temporary files needed to generate "$generated_data/surveys.dta"
**********************************************************************************************************
erase "$generated_data/survey1.dta"
erase "$generated_data/survey2.dta"
erase "$generated_data/survey3.dta"
erase "$generated_data/wave2.dta"



*********************************************************************
*** Create some additional variables
***********************************************************

gen village=(q3==1)
replace village=. if q3==4

gen town=(q3==2)
replace town=. if q3==4

gen city=(q3==3)
replace city=. if q3==4

gen born_france=(q6==1)
replace born_france=. if q6==3

gen father_born_france=(q7==1)
replace born_france=. if q7==3

gen mother_born_france=(q8==1)
replace born_france=. if q8==3

gen children = (q12==1)
replace children =. if q12==.

gen catholic =(q21==1)
*replace catholic =. if q21==8

gen muslim =(q21==4)
*replace muslim =. if q21==8

gen no_religion =(q21==7)
replace no_religion =. if q21==8

gen tv_main_source = (q17==1)
replace tv_main_source =. if q17==9

gen internet_main_source = (q17==3)
replace internet_main_source =. if q17==9

cap drop papers_main_source
gen papers_main_source=(q17==4|q17==5)
replace papers_main_source =. if q17==9

cap drop radio_main_source
gen radio_main_source=(q17==2)
replace radio_main_source =. if q17==9

gen single = (q10==1)
replace single=. if q10==7

gen high_school=q4==7|q4==6

gen higher_education= q4>7

gen civil_partnership = (q10==3)|(q10==4)
replace civil_partnership=. if q10==7

gen young = (age <=35)
gen mid_age = (35< age <65)
gen old = (age >65)

gen religious = (q22 <=4)
gen rel_FC  = (q22 <=4) * (survey ==2)

gen very_religious = (q22 <=2)

 forvalues i=1/7{
replace  q42_`i'=. if q42_`i'==5
}

gen close_gov_europe=(q23==1)
gen close_gov_france=(q23==2)

label var close_gov_europe "Feel closer to European gov."
label var close_gov_france "Feel closer to French gov."

gen registered_vote=(q24==1)

gen distrust_source = ( q42_1 + q42_2 + q42_3 + q42_4 + q42_5 + q42_6 + q42_7 )/7
gen distrust_source_full=distrust_source
replace distrust_source_full=-99 if distrust_source==.
gen  distrust_source_missing=(distrust_source==.)

label var  distrust_source_full "Distrust sources, missing filled"
label var  distrust_source_missing "Distrust sources missing"
label var  distrust_source "Distrust sources"

label var  old "Age group, old"
label var  mid_age "Age group, middle"

label var rel_FC   "Religious x Fact Check" 
label var single "Single"
label var village "Live in village"
label var city "Live in city"
label var town "Live in town"
label var catholic "Religion: catholic"
label var muslim "Religion: muslim"
label var no_religion "Religion: none"
label var born_france "Born in France"
label var father_born_france "Father born in France"
label var mother_born_france "Mother born in France"
label var children "Children"
label var tv_main_source  "Source news: TV"
label var radio_main_source "Source news: Radio"
label var papers_main_source "Source news: Newspapapers"
label var internet_main_source  "Source news: Internet"
label var negative_image_UE "Negative Image EU (1-5)" 

*********************************************************************
*** Define controls
***********************************************************


** education controls

gen mid_educ= (q4==8)
gen high_educ= (q4==9)
gen educ=q4

** reasons to share. We scale all the variables below so that they are measure on a 0,1 scale

gen share_interest=q16_1 / 5
gen share_influence=q16_2 / 5
gen share_image=q16_3 /5
gen share_reciprocity=q16_4 /5

gen altruism = (q18_1+q18_2+q18_3+ q18_4)/20
gen reciprocity = (q19_1+q19_2+q19_3)/15
gen image= q20/5


gen donated_sum = (q18_1+q18_2+q18_4)
gen donated_dummy=(donated_sum>9)
replace donated_dummy=. if donated_sum==.
label var donated_dummy "Top quarter: donated money or blood"

gen money_charity = q18_1 / 5
gen give_money = q18_2 / 5
gen work_charity = q18_3 / 5
gen donate_blood = q18_4 / 5

label var money_charity "Gave money to charity"
label var give_money "Gave money to homeless"
label var work_charity "Worked for charity"
label var donate_blood "Donated blood"
label var educ "Education (1-9)"

** fb controls

gen heavy_use_fb_=(q13<2)

gen daily_use_fb_=(q13<3)
label var daily_use_fb_ "Use FB daily"

gen often_share_fb=(q15==3)


gen nb_friends_fb=q14
replace nb_friends_fb=. if q14>5000

** beliefs

gen perc_laws=q41
label var perc_laws "Action of Sharing laws from EU"

gen perc_laws10=10*perc_laws 
label var perc_laws10 "Perecentage laws from EU"


gen view_website = prob_view_fake
replace view_website = 0 if  prob_view_fake==.

gen sharefb = prob_share_GA_fake
replace sharefb = 0 if  prob_share_GA_fake==.
 
*** Create variable: decision to look at fact checking in survey 3

gen see_facts=q28
replace see_facts=. if q28==3
replace see_facts=0 if survey!=3
 
gen notsee_facts=1-see_facts
replace notsee_facts=0 if survey!=3
 
gen want_share_fb=0
replace want_share_fb=1 if q29==1

gen want_share_others=0
replace want_share_others=1 if q30==1

gen want_share_facts=0
replace want_share_facts=1 if q31==1

gen view=(see_facts==1)

 gen never_share=(q15==1)
 gen rare_share=(q15<=2)
 replace never_share=. if q15==4
 replace rare_share=. if q15==4 

 gen age_sqrd=age*age
 
cap drop region
gen region=q9
replace region=99 if q9>13 | q9==5
cap drop i_region*
tab region, gen(i_region)

gen first_macron_full=first_macron==1
gen first_mlp_full=first_mlp==1
 
 
label var want_share_fb "Want share Alt-Facts on FB"
label var want_share_others "Action of Sharing Alt-Facts with others"
label var want_share_facts "Want share Fact-Check on FB"
label var view "View facts"
label var nb_friends_fb "Nb friends FB"
label var mid_educ "Middle education"
label var heavy_use_fb "Big user FB"
label var often_share_fb "Often share on FB"
label var share_interest "Reason to share: interest" 
label var share_image "Reason to share: image" 
label var share_reciprocity "Reason to share: reciprocity" 
label var share_influence "Reason to share: influence" 
label var image "Self-reported image importance" 
label var reciprocity "Self-reported reciprocity" 
label var altruism "Self-reported altruism" 
label var  first_macron_full "Voted Macron, 1st round 2017"
label var  first_mlp_full "Voted Le Pen, 1st round 2017"

**********************************************************************************
*** define different splits of treatments for graphs
*********************************************************************************


label define treatments   1 "Alt-Facts" 2 "Imposed Fact-Check" 3 "Voluntary Fact-Check" 4 "Control" 5 "Received Alt-Facts from Le Pen supporter"  6 "Received Alt-Facts from Macron supporter"
label values survey treatments
label values survey_id treatments

label var survey "Survey number = treatment"
label var survey_id "Survey number = treatment"


gen survey_alt=survey
replace survey_alt=. if survey>2
replace survey_alt=3 if see_facts==1 & survey==3
replace survey_alt=4 if (see_facts==2|q28==3) & survey==3

label define treatment   1 "Alt-Facts" 2 "Imposed Fact-Check" 3 "Voluntary Fact-Check: Viewer" 4 "Voluntary Fact-Check: Nonviewer"

label values survey_alt treatment

label var survey_alt "Alt-Facts; Imposed Fact-Check; Voluntary Fact-Check Viewer; Voluntary Fact-Check Nonviewer"

gen survey_alt2=survey
replace survey_alt2=. if survey>1
replace survey_alt2=2 if (see_facts==2|q28==3) & survey==3
replace survey_alt2=3 if see_facts==1 & survey==3

label define treatment2   1 "Alt-Facts" 2 "Voluntary Fact-Check: Nonviewer" 3 "Voluntary Fact-Check: Viewer"
label values survey_alt2 treatment2

label var survey_alt2 "Alt-Facts, Voluntary Fact-Check Nonviewer, Voluntary Fact-Check Viewer"

gen survey_alt3=survey
replace survey_alt3=. if survey>2
replace survey_alt3=3 if see_facts==1 & survey==3
replace survey_alt3=4 if (see_facts==2|q28==3) & survey==3
replace survey_alt3=0 if survey==4


label define treatment3   1 "Alt-Facts" 2 "Imposed Fact-Check" 3 "Voluntary Fact-Check: Viewer" 4 "Voluntary Fact-Check: Nonviewer" 0 "Control" 

label values survey_alt3 treatment3

label var survey_alt3 "Alt-Facts, Imposed Fact-Check, Voluntary Fact-Check Viewer, Voluntary Fact-Check Nonviewer, Control" 


gen use_FB =5-q13 
replace use_FB=. if q13==5 

gen log_nb_friends_fb=log(nb_friends_fb+1)
gen small_place=village+town

label var educ "Education level (1-9)"
label var age_sqrd "Age squared"
label var religious "Religious"
label var very_religious "Very religious"
label var second_mlp "Voted Le Pen, 2nd round 2017"
label var use_FB "Frequency of FB use"
label var log_nb_friends_fb "Log (FB friends+1)"

gen share_click1=want_share_fb
replace share_click1=0 if share_click1==.
label var share_click1 "Intent of Sharing  Alt-Facts on FB"

gen share_click2=view_website
replace share_click2=0 if share_click2==.
label var share_click2 "Action of shareingAlt-Facts on FB"

gen share_click3=prob_share_GA_fake
replace share_click3=0 if share_click3==.
label var share_click3 "Reconfirm sharing Alt-Facts on FB"

cap drop id_respondent
gen id_respondent=_n

gen share_facts_click2=prob_view_fact
replace share_facts_click2=0 if share_facts_click2==.
label var share_facts_click2 "Action of sharing Fact-Check on FB"


gen income_full=income
replace income_full=-99 if income==.
gen income_missing = (income_full==-99)

label var income_full "Income with missings"
label var income_missing "Income not reported"

cap drop share_fact_click1
gen share_fact_click1=want_share_facts
replace share_fact_click1=0 if share_fact_click1==.
label var share_fact_click1 "Intent of Sharing  Fact-Check on FB"


cap drop view_website_fact
gen view_website_fact = prob_view_fact
replace view_website_fact = 0 if  prob_view_fact==.

cap drop share_fact_click2
gen share_fact_click2=view_website_fact
replace share_fact_click2=0 if share_fact_click2==.
label var share_fact_click2 "Action of shareingFact-Check on FB"

cap drop share_fact_click3
gen share_fact_click3=prob_share_GA_fact
replace share_fact_click3=0 if share_fact_click3==.
label var share_fact_click3 "Reconfirm sharing Fact-Check on FB"


label var region "Region ID"
label var id_respondent "Respondent ID"
label var high_educ "High education"
label var registered_vote "Regustered to vote, 2019"


label var civil_partnership "In civil partnership"
label var young "Age group, young"
label var donated_sum "q18_1+q18_2+q18_4"

drop view_website sharefb see_facts notsee_facts  never_share rare_share small_place view_website_fact
drop total_prob_view_fake total_prob_share_GA_fake total_participants_fact prob_view_fact prob_share_GA_fact
drop total_prob_view_fact total_prob_share_GA_fact total_participants_fake prob_view_fake prob_share_GA_fake
drop locationlatitude locationlongitude ipaddress recipientlastname recipientfirstname recipientemail

drop year month day hour minutes
label var time "start time"

save "$generated_data/surveys.dta", replace
