**************************************************************************
* This file creates tables and figures for the paper
**************************************************************************


*   NOTE THAT THE PAPER USES THE MAIN EXPERIMENT, WHICH CORRESPONDS TO 
*   TREATMENTS 1, 2, 3 IN VARIBLE "survey"
*   The values of this variable are:
* 1 = “Alt-Facts” treatment, these are DATA FROM THE MAIN EXPERIMENT
* 2 = “Imposed Fact-Check” treatment, these are DATA FROM THE MAIN EXPERIMENT
* 3 = “Voluntary Fact-Check” treatment, these are FROM THE MAIN EXPERIMENT
* 5 = Received Alt-Facts from Le Pen supporter, these are  DATA FROM THE FOLLOW-UP EXPERIMENT, NOT USED IN THE PAPER
* 6 = Received Alt-Facts from Macron supporter, these are  DATA FROM THE FOLLOW-UP EXPERIMENT, NOT USED IN THE PAPER



clear all

use "$dir/generated_data/surveys.dta", clear


**************************************************************************************
**** Globals for sets of controls:
***********************************************************************************

global strata "male"
global strata1 "low_educ mid_educ"
global socio "age age_sqrd income married single village town children catholic muslim no_religion educ religious"
global fb "use_FB often_share_fb log_nb_friends_fb"
global vote "second_mlp negative_image_UE"
global behavioral "altruism reciprocity image"
global reported "share_interest share_influence share_image share_reciprocity"


**************************************************************************************
**** FIGURES MAIN TEXT
***********************************************************************************

***********************************************************
*** Figure 2: Cumulative share on Facebook graphs
***********************************************************

preserve

use "$dir/original_data/share_facebook.dta", clear

gen per=day*24+hour
gen period=per-493

keep if survey_id<4


gen number_share_fact_fb= number_share_fb
replace number_share_fact_fb=0 if fact==0


gen number_share_fake_fb= number_share_fb
replace number_share_fake_fb=0 if fake==0

bysort period: egen share_fake = sum(number_share_fake_fb)   
bysort period: egen share_fact = sum(number_share_fact_fb)   


bysort period : gen id=_n
keep if id==1

**** Redefine date 0 to start the graph when median person startd the survey
gen period_med=period-22
drop if period_med<0
label var period_med "Hours since the median answer"

line share_fake  period_med , graphregion(color(white)) ytitle("Cumulative shares of Alt-Facts on Facebook")  lpattern(solid) lwidth(thick) title("Alt-Facts") 
graph save "$dir/results/figures/cum_shares_altfacts", replace
sum share_fake

line share_fact period_med, graphregion(color(white)) ytitle("Cumulative shares of Fact-Check on Facebook")  lpattern(dash) lcolor(ebblue) lwidth(thick) title("Fact-Check")

graph save "$dir/results/figures/cum_shares_factcheck" , replace


graph combine "$dir/results/figures/cum_shares_altfacts" "$dir/results/figures/cum_shares_factcheck" , title("Cumulative propagation of Alt-Facts and Fact-Check on Facebook") subtitle("(including resharing by users outside the experiment)") graphregion(color(white)) 

graph save "$dir/results/figures/Figure_2", replace
erase "$dir/results/figures/cum_shares_altfacts.gph"
erase "$dir/results/figures/cum_shares_factcheck.gph"

restore

**********************************************************************
******* Figure 3: probability of sharing by number of clicks
***********************************************************************

**********************************************************************
******* Figure 3, Panel A


preserve 

reshape long share_click, i(id_respondent) j(number_clicks)

label define nclicks 1 "Sharing intention" 2 "Sharing action" 3 "Reconfirm sharing"
label values number_clicks nclicks 

cibar share_click if survey<4, over1(number_clicks) over2(survey) barcol(ltkhaki dkorange sienna)  ///
graphopts(graphregion(fcolor(white))    ///
yscale(log) ylabel(0.005 0.01 0.02 0.05 0.1 0.2) legend( label(1 "One click") cols(3)) ///
ytitle("Probability of sharing Alt-Facts, log scale") title("Sharing Alt-Facts by the number of clicks to share") subtitle("(in each treatment)"))

graph save "$dir/results/figures/Figure 3_Panel_A", replace

restore

**********************************************************************
******* Figure 3, Panel B

preserve 

reshape long share_fact_click, i(id_respondent) j(number_clicks)

label define nclicks  1 "Sharing intention" 2 "Sharing action" 3 "Reconfirm sharing"
label values number_clicks nclicks 

cibar share_fact_click if survey_alt==2 | survey_alt==3, over1(number_clicks) over2(survey_alt) barcol(ltkhaki dkorange sienna)  ///
graphopts(graphregion(fcolor(white))    ///
yscale(log) ylabel(0 0.005 0.01 0.02 0.05 0.1 0.2 0.4) legend( label(1 "One click") cols(3)) ///
ytitle("Probability of sharing Fact-Check, log scale") title("Sharing Fact-Check by the number of clicks to share") subtitle("(in each treatment)"))  

graph save "$dir/results/figures/Figure 3_Panel_B", replace

restore


**********************************************************************
******* Figure 4: ATE
***********************************************************************

*** Figure 3 Panel A

cibar  want_share_fb if survey<4, over1(survey) barcol(ltblue emidblue dknavy) graphopts(title("Intent of Sharing Alt-Facts") graphregion(color(white)) ytitle("Intent of Sharing Alt-Facts on FB"  " ") ysc(range(0 0.2)) ylabel(0 (0.05) 0.2) legend(cols(1)))  bargap(20)
graph save "$dir/results/figures/ATE_altfacts", replace

cibar  share_click2 if survey<4, over1(survey) barcol(ltblue emidblue dknavy) graphopts(title("Action of Sharing Alt-Facts") graphregion(color(white)) ytitle("Action of Sharing Alt-Facts on FB" " ") ysc(range(0 0.06)) ylabel(0 (0.02) 0.06) legend(cols(1)))  bargap(20)
graph save "$dir/results/figures/ATE_altfacts_2clicks", replace

grc1leg "$dir/results/figures/ATE_altfacts" "$dir/results/figures/ATE_altfacts_2clicks", graphregion(color(white)) legendfrom("$dir/results/figures/ATE_altfacts")		
graph save "$dir/results/figures/Figure_4_Panel_A", replace

*** Figure 3 Panel B

cibar  want_share_facts if survey>1&survey<4, over1(survey) barcol(emidblue dknavy)  graphopts(title("Intent of Sharing  Fact-Check") graphregion(color(white))  ytitle("Intent of Sharing  Fact-Check on FB" " ") ysc(range(0 0.2)) ylabel(0 (0.05) 0.2) legend(cols(1)))  bargap(20) 
graph save "$dir/results/figures/ATE_factcheck", replace

cibar  share_facts_click2 if survey>1&survey<4, over1(survey) barcol(emidblue dknavy) graphopts(title("Action of Sharing Fact-Check") graphregion(color(white)) ytitle("Action of Sharing Fact-Check on FB" " ") ysc(range(0 0.05)) ylabel(0 (0.01) 0.05) legend(cols(1)))  bargap(20)
graph save "$dir/results/figures/ATE_factcheck_2clicks", replace

grc1leg "$dir/results/figures/ATE_factcheck" "$dir/results/figures/ATE_factcheck_2clicks", graphregion(color(white)) legendfrom("$dir/results/figures/ATE_factcheck")		
graph save "$dir/results/figures/Figure_4_Panel_B", replace

erase "$dir/results/figures/ATE_factcheck.gph" 
erase "$dir/results/figures/ATE_factcheck_2clicks.gph"
erase "$dir/results/figures/ATE_altfacts.gph" 
erase "$dir/results/figures/ATE_altfacts_2clicks.gph"



**********************************************************************
******* Figure 5 (WITH LASSO): actual sharing compared to predicted sharing
******* Table A5 (LASSO RESULTS)
***********************************************************************


set seed 1234
set sortseed 1234

global pre_treatment_vars age village city educ male born_france father_born_france mother_born_france married single income_missing income_full children use_FB log_nb_friends_fb often_share_fb share_interest share_influence share_image share_reciprocity  tv_main_source internet_main_source  altruism  reciprocity image money_charity  give_money  work_charity donate_blood  religious catholic muslim close_gov_europe close_gov_france first_mlp  second_mlp negative_image_UE first_macron



**********************************************************************
******* Figure 5, Panel A
***********************************************************************

**** to do lasso, define the sample with all pre-treatment variables non-missing
cap drop restriction
gen restriction=1
foreach var in $pre_treatment_vars{
	replace restriction=0 if `var'==.
}
label var restriction "Sample with pre-treatment vars non-missing"

* Panel A left
* Intend share alt facts (without indend to sharing fact check)

cap drop want_share_alt_facts
gen want_share_alt_facts=want_share_fb

lasso linear want_share_alt_facts  $pre_treatment_vars if survey==1&restriction==1 ,  selection(adaptive) rseed(1234)
local selected1="`e(allvars_sel)'"

cap drop pred_want_share_altfact
predict pred_want_share_altfact if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)

local lasso table_A5

reg want_share_alt_facts `selected1' if survey==1, r
outreg2 using "$dir/results/tables/`lasso'.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 

sum want_share_alt_facts if  sample_survey_1==1&restriction==1
scalar M1 = r(mean)
local m1 =M1

sum pred_want_share_altfact if  survey_alt==3&restriction==1
scalar M2 = r(mean)
local m2 =M2

 
cibar  want_share_alt_facts if survey_alt<5 & pred_want_share_altfact!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Intent" "Alt-Facts") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 (0.05) 0.25)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save actual_a_l, replace

cibar  pred_want_share_altfact if survey_alt<5 & pred_want_share_altfact!=.&restriction==1  , over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Intent" "Alt-Facts") graphregion(color(white))   ytitle("") legend(off) ysc(range(0 (0.05) 0.25)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save predicted_a_l, replace

graph combine  actual_a_l.gph predicted_a_l.gph, graphregion(color(white)) ycommon title("Panel A.1", size(medlarge)) graphregion(margin(zero))	 	

graph save "$dir/results/figures/figure_5_panel_a_left", replace



**********************************************************************

* Panel A right
* Intend to Share alt facts (without intend to share facts)
 
lasso linear share_click2  $pre_treatment_vars if survey==1&restriction==1 ,  selection(adaptive) rseed(1234) 
local selected2="`e(allvars_sel)'"

cap drop predicted_share_altfact
predict predicted_share_altfact if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)


reg share_click2 `selected2' if survey==1, r
outreg2 using "$dir/results/tables/`lasso'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 


sum share_click2 if  sample_survey_1==1
scalar M1 = r(mean)
local m1 =M1

sum predicted_share_altfact if  survey_alt==3
scalar M2 = r(mean)
local m2 =M2

cibar  share_click2 if survey_alt<5 & predicted_share_altfact!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Action" "Alt-Facts") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 0.08)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save share1_altfacts_a_r, replace

cibar  predicted_share_altfact if survey_alt<5 & predicted_share_altfact!=.  &restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Action" "Alt-Facts") graphregion(color(white))   ytitle("") legend(off)  ysc(range(0 0.08)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save share2_altfacts_a_r, replace

graph combine   share1_altfacts_a_r.gph share2_altfacts_a_r.gph, graphregion(color(white))  ycommon title("Panel A.2", size(medlarge))  graphregion(margin(zero))	 	  	 	

graph save "$dir/results/figures/figure_5_panel_a_right", replace


**********************************************************************
******* Figure 5, Panel B
***********************************************************************


* Panel B left
* Intend to share fact check (without indend to share alt facts)

cap drop want_share_factcheck
gen want_share_factcheck=want_share_facts

lasso linear want_share_factcheck  $pre_treatment_vars if survey==2&restriction==1 ,  selection(adaptive) rseed(1234) 
local selected3="`e(allvars_sel)'"

cap drop pred_want_share_factcheck
predict pred_want_share_factcheck if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)



reg want_share_factcheck `selected3' if survey==2, r
outreg2 using "$dir/results/tables/`lasso'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 


sum want_share_factcheck if  sample_survey_1==1
scalar M1 = r(mean)
local m1 =M1

sum pred_want_share_factcheck if  survey_alt==3
scalar M2 = r(mean)
local m2 =M2

 
cibar  want_share_factcheck if survey_alt<5 & pred_want_share_factcheck!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Intent" "Fact-Check") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 0.25)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save actual_b_l, replace

cibar  pred_want_share_factcheck if survey_alt<5 & pred_want_share_factcheck!=.  &restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Intent" "Fact-Check") graphregion(color(white))   ytitle("") legend(off)  ysc(range(0 0.25)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save predicted_b_l, replace

graph combine  actual_b_l.gph predicted_b_l.gph, graphregion(color(white))  ycommon title("Panel B.1", size(medlarge)) graphregion(margin(zero))

graph save "$dir/results/figures/figure_5_panel_b_left", replace


**********************************************************************

* Panel B right
* Share fact check (without indend to share alt facts)

cap drop share_factcheck
gen share_factcheck= share_facts_click2


cap drop predicted_share_factcheck
lasso linear share_factcheck  $pre_treatment_vars if survey==2&restriction==1 ,  selection(adaptive) rseed(1234) 
local selected4="`e(allvars_sel)'"

predict predicted_share_factcheck if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)



reg share_factcheck `selected4' if survey==2, r
outreg2 using "$dir/results/tables/`lasso'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 


sum share_factcheck if  sample_survey_1==1
scalar M1 = r(mean)
local m1 =M1

sum predicted_share_factcheck if  survey_alt==3
scalar M2 = r(mean)
local m2 =M2

 
cibar  share_factcheck if survey_alt<5 & predicted_share_factcheck!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Action" "Fact-Check") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 0.08)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save actual_b_r, replace

cibar  predicted_share_factcheck if survey_alt<5 & predicted_share_factcheck!=.  &restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Action" "Fact-Check") graphregion(color(white))   ytitle("") legend(off)  ysc(range(0 0.08)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save predicted_b_r, replace


graph combine  actual_b_r.gph  predicted_b_r.gph, graphregion(color(white))  ycommon title("Panel B.2", size(medlarge)) graphregion(margin(zero))

graph save "$dir/results/figures/figure_5_panel_b_right", replace


graph combine "$dir/results/figures/figure_5_panel_a_left" "$dir/results/figures/figure_5_panel_a_right"  "$dir/results/figures/figure_5_panel_b_left" "$dir/results/figures/figure_5_panel_b_right" , cols(2)  graphregion(margin(zero))
graph save "$dir/results/figures/figure_5_all", replace						 


erase "$dir/results/figures/figure_5_panel_a_left.gph" 
erase "$dir/results/figures/figure_5_panel_a_right.gph"  
erase "$dir/results/figures/figure_5_panel_b_left.gph" 
erase "$dir/results/figures/figure_5_panel_b_right.gph"

erase actual_a_l.gph
erase predicted_a_l.gph
erase share1_altfacts_a_r.gph
erase share2_altfacts_a_r.gph
erase actual_b_l.gph
erase predicted_b_l.gph
erase actual_b_r.gph
erase predicted_b_r.gph



**********************************************************************
******* Figure 6 (WITH LASSO): actual sharing of BOTH or ONLY compared to predicted sharing
******* Table A7 (LASSO RESULTS)
***********************************************************************

**********************************************************************
******* Figure 6, Panel A
***********************************************************************

**** to do lasso, define the sample with all pre-treatment variables non-missing
cap drop restriction
gen restriction=1
foreach var in $pre_treatment_vars{
	replace restriction=0 if `var'==.
}
label var restriction "Sample with pre-treatment vars non-missing"

* Panel A left
* Intend share alt facts only (without indend to sharing fact check)

cap drop want_share_alt_facts_only
gen want_share_alt_facts_only=want_share_fb
replace want_share_alt_facts_only=0 if want_share_facts==1

lasso linear want_share_alt_facts_only  $pre_treatment_vars if survey==1&restriction==1 ,  selection(adaptive) rseed(1234)
local selected1="`e(allvars_sel)'"

cap drop pred_want_share_altfact_only
predict pred_want_share_altfact_only if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)

local lasso table_A7

reg want_share_alt_facts_only `selected1' if survey==1, r
outreg2 using "$dir/results/tables/`lasso'.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 

sum want_share_alt_facts_only if  sample_survey_1==1&restriction==1
scalar M1 = r(mean)
local m1 =M1

sum pred_want_share_altfact_only if  survey_alt==3&restriction==1
scalar M2 = r(mean)
local m2 =M2

 
cibar  want_share_alt_facts_only if survey_alt<5 & pred_want_share_altfact_only!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Intent" "Alt-Facts Only") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 (0.05) 0.25)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save actual_a_l, replace

cibar  pred_want_share_altfact_only if survey_alt<5 & pred_want_share_altfact_only!=.&restriction==1  , over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Intent" "Alt-Facts Only") graphregion(color(white))   ytitle("") legend(off) ysc(range(0 (0.05) 0.25)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save predicted_a_l, replace

graph combine  actual_a_l.gph predicted_a_l.gph, graphregion(color(white)) ycommon title("Panel A.1", size(medlarge)) graphregion(margin(zero))	 	

graph save "$dir/results/figures/figure_6_panel_a_left", replace



**********************************************************************

cap drop share_both
gen share_both=share_facts_click2*share_click2 



* Panel A right
* Intend to Share alt facts only (without intend to share facts)

cap drop share_click2_only
gen share_click2_only=share_click2-share_both
 
lasso linear share_click2_only  $pre_treatment_vars if survey==1&restriction==1 ,  selection(adaptive) rseed(1234) 
local selected2="`e(allvars_sel)'"

cap drop predicted_share_altfact
predict predicted_share_altfact if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)


reg share_click2_only `selected2' if survey==1, r
outreg2 using "$dir/results/tables/`lasso'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 


sum share_click2_only if  sample_survey_1==1
scalar M1 = r(mean)
local m1 =M1

sum predicted_share_altfact if  survey_alt==3
scalar M2 = r(mean)
local m2 =M2

cibar  share_click2_only if survey_alt<5 & predicted_share_altfact!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Action" "Alt-Facts Only") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 0.08)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save share1_altfacts_a_r, replace

cibar  predicted_share_altfact if survey_alt<5 & predicted_share_altfact!=.  &restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Action" "Alt-Facts Only") graphregion(color(white))   ytitle("") legend(off)  ysc(range(0 0.08)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save share2_altfacts_a_r, replace

graph combine   share1_altfacts_a_r.gph share2_altfacts_a_r.gph, graphregion(color(white))  ycommon title("Panel A.2", size(medlarge))  graphregion(margin(zero))	 	  	 	

graph save "$dir/results/figures/figure_6_panel_a_right", replace


**********************************************************************
******* Figure 6, Panel B
***********************************************************************


* Panel B left
* Intend to share fact check only (without indend to share alt facts)

cap drop want_share_factcheck_only
gen want_share_factcheck_only=want_share_facts
replace want_share_factcheck_only=0 if want_share_fb==1

lasso linear want_share_factcheck_only  $pre_treatment_vars if survey==2&restriction==1 ,  selection(adaptive) rseed(1234) 
local selected3="`e(allvars_sel)'"

cap drop pred_want_share_factcheck_only
predict pred_want_share_factcheck_only if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)



reg want_share_factcheck_only `selected3' if survey==2, r
outreg2 using "$dir/results/tables/`lasso'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 


sum want_share_factcheck_only if  sample_survey_1==1
scalar M1 = r(mean)
local m1 =M1

sum pred_want_share_factcheck_only if  survey_alt==3
scalar M2 = r(mean)
local m2 =M2

 
cibar  want_share_factcheck_only if survey_alt<5 & pred_want_share_factcheck_only!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Intent" "Fact-Check Only") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 0.25)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save actual_b_l, replace

cibar  pred_want_share_factcheck_only if survey_alt<5 & pred_want_share_factcheck_only!=.  &restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Intent" "Fact-Check Only") graphregion(color(white))   ytitle("") legend(off)  ysc(range(0 0.25)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save predicted_b_l, replace

graph combine  actual_b_l.gph predicted_b_l.gph, graphregion(color(white))  ycommon title("Panel B.1", size(medlarge)) graphregion(margin(zero))

graph save "$dir/results/figures/figure_6_panel_b_left", replace


**********************************************************************

* Panel B right
* Share fact check only (without indend to share alt facts)

cap drop share_factcheck_only
gen share_factcheck_only= share_facts_click2-share_both


cap drop predicted_share_factcheck_only
lasso linear share_factcheck_only  $pre_treatment_vars if survey==2&restriction==1 ,  selection(adaptive) rseed(1234) 
local selected4="`e(allvars_sel)'"

predict predicted_share_factcheck_only if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)



reg share_factcheck_only `selected4' if survey==2, r
outreg2 using "$dir/results/tables/`lasso'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 


sum share_factcheck_only if  sample_survey_1==1
scalar M1 = r(mean)
local m1 =M1

sum predicted_share_factcheck_only if  survey_alt==3
scalar M2 = r(mean)
local m2 =M2

 
cibar  share_factcheck_only if survey_alt<5 & predicted_share_factcheck_only!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Action" "Fact-Check Only") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 0.08)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save actual_b_r, replace

cibar  predicted_share_factcheck_only if survey_alt<5 & predicted_share_factcheck_only!=.  &restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Action" "Fact-Check Only") graphregion(color(white))   ytitle("") legend(off)  ysc(range(0 0.08)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save predicted_b_r, replace

graph combine   actual_b_r.gph predicted_b_r.gph, graphregion(color(white))  ycommon title("Panel B.2", size(medlarge)) graphregion(margin(zero))

graph save "$dir/results/figures/figure_6_panel_b_right", replace


**********************************************************************
******* Figure 6, Panel C
***********************************************************************


* Panel C left
* want to share both fact check and alt facts


cap drop want_share_both
gen want_share_both=1 if (want_share_facts==1 & want_share_fb==1)
replace want_share_both=0 if (want_share_facts!=1 | want_share_fb!=1)

cap drop predicted_want_share_both

lasso linear want_share_both $pre_treatment_vars if survey==2&restriction==1 ,  selection(adaptive) rseed(1234) 
local selected5="`e(allvars_sel)'"

predict predicted_want_share_both if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)

reg want_share_both `selected5' if survey==2, r
outreg2 using "$dir/results/tables/`lasso'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 


sum want_share_both if  sample_survey_1==1
scalar M1 = r(mean)
local m1 =M1

sum predicted_want_share_both if  survey_alt==3
scalar M2 = r(mean)
local m2 =M2

 
cibar  want_share_both if survey_alt<5 & predicted_want_share_both!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Intent" "Alt-Facts & Fact-Check") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 0.15)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save actual_c_l, replace

cibar  predicted_want_share_both if survey_alt<5 & predicted_want_share_both!=.  &restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Intent" "Alt-Facts & Fact-Check") graphregion(color(white))   ytitle("") legend(off)  ysc(range(0 0.15)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save predicted_c_l, replace

graph combine  actual_c_l.gph predicted_c_l.gph, graphregion(color(white))  ycommon title("Panel C.1", size(medlarge)) graphregion(margin(zero))

graph save "$dir/results/figures/figure_6_panel_c_left", replace



**********************************************************************

* Panel C right
* share fact check if want to share both 

cap drop predicted_share_both

lasso linear share_both  $pre_treatment_vars if survey==2&restriction==1 ,  selection(adaptive) rseed(1234) 

local selected6="`e(allvars_sel)'"

predict predicted_share_both if survey<4, xb
cap drop sample_survey_1
gen sample_survey_1=e(sample)


reg share_both `selected6' if survey==2, r
outreg2 using "$dir/results/tables/`lasso'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes 


sum share_both if  sample_survey_1==1
scalar M1 = r(mean)
local m1 =M1

sum predicted_share_both if  survey_alt==3
scalar M2 = r(mean)
local m2 =M2

 
cibar  share_both if survey_alt<5 & predicted_share_both!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Action" "Alt-Facts & Fact-Check") graphregion(color(white))  ytitle("") legend(off)  ysc(range(0 0.015)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save actual_c_r, replace

cibar  predicted_share_both if survey_alt<5 & predicted_share_both!=.  &restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Predicted: Sharing Action" "Alt-Facts & Fact-Check") graphregion(color(white))   ytitle("") legend(off)  ysc(range(0 0.015)) ylabel(,nogrid) yline(`m1' `m2', lpattern(dash) lcolor(brown)))  bargap(20) 
graph save predicted_c_r, replace

graph combine  actual_c_r.gph predicted_c_r.gph, graphregion(color(white))  ycommon title("Panel C.2", size(medlarge))graphregion(margin(zero))

graph save "$dir/results/figures/figure_6_panel_c_right", replace


graph combine "$dir/results/figures/figure_6_panel_a_left" "$dir/results/figures/figure_6_panel_a_right"  "$dir/results/figures/figure_6_panel_b_left" "$dir/results/figures/figure_6_panel_b_right" "$dir/results/figures/figure_6_panel_c_left" "$dir/results/figures/figure_6_panel_c_right" , cols(2) iscale(.6) ysize(7)  graphregion(margin(zero))
graph save "$dir/results/figures/figure_6_all", replace						 


erase actual_a_l.gph
erase predicted_a_l.gph
erase share1_altfacts_a_r.gph
erase share2_altfacts_a_r.gph
erase actual_b_l.gph
erase predicted_b_l.gph
erase actual_b_r.gph
erase predicted_b_r.gph
erase actual_c_l.gph
erase predicted_c_l.gph
erase actual_c_r.gph
erase predicted_c_r.gph


erase  "$dir/results/figures/figure_6_panel_a_left.gph" 
erase "$dir/results/figures/figure_6_panel_a_right.gph" 
erase  "$dir/results/figures/figure_6_panel_b_left.gph" 
erase "$dir/results/figures/figure_6_panel_b_right.gph"
erase  "$dir/results/figures/figure_6_panel_c_left.gph" 
erase "$dir/results/figures/figure_6_panel_c_right.gph"
 

cibar  share_click2_only if survey_alt<5 & predicted_share_both!=.&restriction==1, over1(survey_alt) barcol(ltblue emidblue edkblue black) graphopts(title("Actual: Sharing Action" "Alt-Facts & Fact-Check") graphregion(color(white))  ytitle("") legend(col(2) order(1 "Alt-Facts" 3 "Voluntary Fact-Check: Viewer" 2 "Imposed Fact-Check" 4 "Voluntary Fact-Check: Nonviewer"))  ysc(range(0 0.015))  )
graph save "$dir/results/figures/legend", replace


***********************************************************************************
**** TABLES MAIN TEXT, AND SOME APPENDIX TABLES
***********************************************************************************

**********************************************************************
******* Table 1: Balancing table, Sharing experiment
***********************************************************************

cd   "$dir/results/tables/" 

local tabnom  "Table_1"
 
global pre_treatment_vars_t1 male educ born_france father_born_france mother_born_france age village city  married single income children use_FB log_nb_friends_fb often_share_fb share_interest share_influence share_image share_reciprocity  tv_main_source internet_main_source  altruism  reciprocity image money_charity  give_money  work_charity donate_blood  religious catholic muslim close_gov_europe close_gov_france negative_image_UE first_mlp_full  first_macron_full second_mlp


eststo domestic: quietly estpost summarize ///
     $pre_treatment_vars_t1   if survey == 1  
eststo foreign: quietly estpost summarize ///
     $pre_treatment_vars_t1     if survey==2
eststo foreign2: quietly estpost summarize ///
     $pre_treatment_vars_t1     if survey==3
eststo diff: quietly estpost ttest ///
     $pre_treatment_vars_t1     if   survey<3, by(survey) unequal
eststo diff2: quietly estpost ttest ///
     $pre_treatment_vars_t1     if   survey==1 | survey==3, by(survey) unequal
eststo diff3: quietly estpost ttest ///
     $pre_treatment_vars_t1     if   survey==2 | survey==3, by(survey) unequal
   
esttab domestic foreign foreign2 diff diff2 diff3 , ///
cells("mean(pattern(1 1 1 0 0 0) fmt(2)) sd(pattern(1 1 1 0 0 0)) b(pattern(0 0 0 1 1 1) fmt(2)) p(pattern(0 0 0 1 1 1) par fmt(2))") ///
label


esttab  domestic foreign foreign2 diff diff2 diff3 using `tabnom'.tex, replace ///
cells("mean(pattern(1 1 1 0 0 0) fmt(2)) sd(pattern(1 1 1 0 0 0)) b(pattern(0 0 0 1 1 1) fmt(2)) p(pattern(0 0 0 1 1 1) par fmt(2))") ///
label



**********************************************************************
******* Table OMNIBUS TEST: Balance, Sharing experiment
***********************************************************************

cd   "$dir/results/tables/" 

cap tab region, gen(i_region)

local tabnom  "Table_A1"
 

global pre_treatment_vars_all mid_educ high_educ old mid_age age age_sqrd male born_france  village city father_born_france mother_born_france married single income children use_FB log_nb_friends_fb often_share_fb share_interest share_influence share_image share_reciprocity  tv_main_source internet_main_source radio_main_source papers_main_source  altruism  reciprocity image money_charity  give_money  work_charity donate_blood  religious very_religious catholic muslim close_gov_europe close_gov_france negative_image_UE first_mlp_full  first_macron_full second_mlp registered_vote  i_region1 i_region2 i_region3 i_region4 i_region5 i_region6 i_region7 i_region8 i_region9 i_region10 i_region11 i_region12 i_region13 


cap drop imposed_tr volunt_tr
gen imposed_tr=(survey==2)
gen volunt_tr=(survey==3)

log using "$dir/results/tables/`tabnom'", replace
mlogit survey $pre_treatment_vars_all if survey<4, r
test $pre_treatment_vars_all
scalar p_all = r(p)


test  [Voluntary_Fact_Check]mid_educ [Voluntary_Fact_Check]high_educ [Voluntary_Fact_Check]old [Voluntary_Fact_Check]mid_age [Voluntary_Fact_Check]age [Voluntary_Fact_Check]age_sqrd [Voluntary_Fact_Check]male [Voluntary_Fact_Check]born_france [Voluntary_Fact_Check]village [Voluntary_Fact_Check]city [Voluntary_Fact_Check]father_born_france [Voluntary_Fact_Check]mother_born_france [Voluntary_Fact_Check]married [Voluntary_Fact_Check]single [Voluntary_Fact_Check]income [Voluntary_Fact_Check]children [Voluntary_Fact_Check]use_FB [Voluntary_Fact_Check]log_nb_friends_fb [Voluntary_Fact_Check]often_share_fb [Voluntary_Fact_Check]share_interest [Voluntary_Fact_Check]share_influence [Voluntary_Fact_Check]share_image [Voluntary_Fact_Check]share_reciprocity [Voluntary_Fact_Check]tv_main_source [Voluntary_Fact_Check]internet_main_source [Voluntary_Fact_Check]radio_main_source [Voluntary_Fact_Check]papers_main_source [Voluntary_Fact_Check]altruism [Voluntary_Fact_Check]reciprocity [Voluntary_Fact_Check]image [Voluntary_Fact_Check]money_charity [Voluntary_Fact_Check]give_money [Voluntary_Fact_Check]work_charity [Voluntary_Fact_Check]donate_blood [Voluntary_Fact_Check]religious [Voluntary_Fact_Check]very_religious [Voluntary_Fact_Check]catholic [Voluntary_Fact_Check]muslim [Voluntary_Fact_Check]close_gov_europe [Voluntary_Fact_Check]close_gov_france [Voluntary_Fact_Check]negative_image_UE [Voluntary_Fact_Check]first_mlp_full [Voluntary_Fact_Check]first_macron_full [Voluntary_Fact_Check]second_mlp [Voluntary_Fact_Check]registered_vote [Voluntary_Fact_Check]i_region1 [Voluntary_Fact_Check]i_region2 [Voluntary_Fact_Check]i_region3 [Voluntary_Fact_Check]i_region4 [Voluntary_Fact_Check]i_region5 [Voluntary_Fact_Check]i_region6 [Voluntary_Fact_Check]i_region7 [Voluntary_Fact_Check]i_region8 [Voluntary_Fact_Check]i_region9 [Voluntary_Fact_Check]i_region10 [Voluntary_Fact_Check]i_region11 [Voluntary_Fact_Check]i_region12 [Voluntary_Fact_Check]i_region13 
scalar p_Voluntary_Fact_Check = r(p)

test  [Imposed_Fact_Check]mid_educ [Imposed_Fact_Check]high_educ [Imposed_Fact_Check]old [Imposed_Fact_Check]mid_age [Imposed_Fact_Check]age [Imposed_Fact_Check]age_sqrd [Imposed_Fact_Check]male [Imposed_Fact_Check]born_france [Imposed_Fact_Check]village [Imposed_Fact_Check]city [Imposed_Fact_Check]father_born_france [Imposed_Fact_Check]mother_born_france [Imposed_Fact_Check]married [Imposed_Fact_Check]single [Imposed_Fact_Check]income [Imposed_Fact_Check]children [Imposed_Fact_Check]use_FB [Imposed_Fact_Check]log_nb_friends_fb [Imposed_Fact_Check]often_share_fb [Imposed_Fact_Check]share_interest [Imposed_Fact_Check]share_influence [Imposed_Fact_Check]share_image [Imposed_Fact_Check]share_reciprocity [Imposed_Fact_Check]tv_main_source [Imposed_Fact_Check]internet_main_source [Imposed_Fact_Check]radio_main_source [Imposed_Fact_Check]papers_main_source [Imposed_Fact_Check]altruism [Imposed_Fact_Check]reciprocity [Imposed_Fact_Check]image [Imposed_Fact_Check]money_charity [Imposed_Fact_Check]give_money [Imposed_Fact_Check]work_charity [Imposed_Fact_Check]donate_blood [Imposed_Fact_Check]religious [Imposed_Fact_Check]very_religious [Imposed_Fact_Check]catholic [Imposed_Fact_Check]muslim [Imposed_Fact_Check]close_gov_europe [Imposed_Fact_Check]close_gov_france [Imposed_Fact_Check]negative_image_UE [Imposed_Fact_Check]first_mlp_full [Imposed_Fact_Check]first_macron_full [Imposed_Fact_Check]second_mlp [Imposed_Fact_Check]registered_vote [Imposed_Fact_Check]i_region1 [Imposed_Fact_Check]i_region2 [Imposed_Fact_Check]i_region3 [Imposed_Fact_Check]i_region4 [Imposed_Fact_Check]i_region5 [Imposed_Fact_Check]i_region6 [Imposed_Fact_Check]i_region7 [Imposed_Fact_Check]i_region8 [Imposed_Fact_Check]i_region9 [Imposed_Fact_Check]i_region10 [Imposed_Fact_Check]i_region11 [Imposed_Fact_Check]i_region12 [Imposed_Fact_Check]i_region13 
scalar p_Imposed_Fact_Check = r(p)


log close

***********************************************************
*** Table 2, Panel A: ATE on sharing alt facts
*** Table A3
***********************************************************

local TabATE_all Table_2_panel_A 

local TabATEw1_wp Table_A3 

reg want_share_fb i.survey  if survey<4, r
sum want_share_fb if e(sample)&survey==1
scalar y_contr = r(mean)
test 2.survey - 3.survey = 0
scalar p_2_3 = r(p)

outreg2 using "$dir/results/tables/`TabATEw1_wp'.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey) 

reg want_share_fb i.survey $strata $strata1 if survey<4, r
sum want_share_fb if e(sample)&survey==1
scalar y_contr = r(mean)
test 2.survey - 3.survey = 0
scalar p_2_3 = r(p)

outreg2 using "$dir/results/tables/`TabATEw1_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)  


reg want_share_fb i.survey   $strata $strata1 $socio $vote  $fb i.educ  if survey<4, r
sum want_share_fb if e(sample)&survey==1
scalar y_contr = r(mean)
test 2.survey - 3.survey = 0
scalar p_2_3 = r(p)

outreg2 using "$dir/results/tables/`TabATEw1_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3)  keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)  


reg want_share_fb i.survey   $strata $strata1 $socio $vote $fb   $reported  $behavioral i.educ $pre_treatment_vars_all if survey<4, r
sum want_share_fb if e(sample)&survey==1
scalar y_contr = r(mean) 
test 2.survey - 3.survey = 0
scalar p_2_3 = r(p)

outreg2 using "$dir/results/tables/`TabATEw1_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3)  keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 


outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)  

reg share_click2 i.survey  if survey<4, r
sum share_click2 if e(sample)&survey==1
scalar y_contr = r(mean)
test 2.survey - 3.survey = 0
scalar p_2_3 = r(p)

outreg2 using "$dir/results/tables/`TabATEw1_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)  

reg share_click2 i.survey $strata $strata1 if survey<4, r
sum share_click2 if e(sample)&survey==1
scalar y_contr = r(mean)
test 2.survey - 3.survey = 0
scalar p_2_3 = r(p)

outreg2 using "$dir/results/tables/`TabATEw1_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)  

reg share_click2 i.survey   $strata $strata1 $socio $vote  $fb  i.educ if survey<4, r
sum share_click2 if e(sample)&survey==1
scalar y_contr = r(mean)
test 2.survey - 3.survey = 0
scalar p_2_3 = r(p)

outreg2 using "$dir/results/tables/`TabATEw1_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3)  keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)  

reg share_click2 i.survey   $strata $strata1 $socio $vote $fb   $reported  $behavioral i.educ $pre_treatment_vars_all if survey<4, r
sum share_click2 if e(sample)&survey==1
scalar y_contr = r(mean) 
test 2.survey - 3.survey = 0
scalar p_2_3 = r(p)

outreg2 using "$dir/results/tables/`TabATEw1_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3)  keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV alt-facts treatment, y_contr, pvalue, p_2_3) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)  

***********************************************************
*** Table 2, Panel B: ATE on sharing factcheck
*** Table A4
***********************************************************

local TabATE_all Table_2_panel_B 

local TabATEw1_wp_fc Table_A4

reg want_share_facts i.survey  if survey<4&survey>1, r
sum want_share_facts if e(sample)&survey==2
scalar y_contr = r(mean)

outreg2 using "$dir/results/tables/`TabATEw1_wp_fc'.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr)  keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity)


outreg2 using "$dir/results/tables/`TabATE_all'.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr)  keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)

reg want_share_facts i.survey $strata $strata1 if survey<4&survey>1, r
sum want_share_facts if e(sample)&survey==2
scalar y_contr = r(mean)

outreg2 using "$dir/results/tables/`TabATEw1_wp_fc'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity)

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)


reg want_share_facts i.survey   $strata $strata1 $socio $vote  $fb  i.educ  if survey<4&survey>1, r
sum want_share_facts if e(sample)&survey==2
scalar y_contr = r(mean)

outreg2 using "$dir/results/tables/`TabATEw1_wp_fc'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity)


outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)

reg want_share_facts i.survey   $strata $strata1 $socio $vote $fb   $reported  $behavioral i.educ $pre_treatment_vars_all if survey<4&survey>1, r
sum want_share_facts if e(sample)&survey==2
scalar y_contr = r(mean)

outreg2 using "$dir/results/tables/`TabATEw1_wp_fc'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr)  keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity)

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)

reg share_facts_click2 i.survey  if survey<4&survey>1, r
sum share_facts_click2 if e(sample)&survey==2
scalar y_contr = r(mean)

outreg2 using "$dir/results/tables/`TabATEw1_wp_fc'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr)  keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity)

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)

reg share_facts_click2 i.survey $strata $strata1 if survey<4&survey>1, r
sum share_facts_click2 if e(sample)&survey==2
scalar y_contr = r(mean)

outreg2 using "$dir/results/tables/`TabATEw1_wp_fc'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity)

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)

reg share_facts_click2 i.survey   $strata $strata1 $socio $vote  $fb   if survey<4&survey>1, r
sum share_facts_click2 if e(sample)&survey==2
scalar y_contr = r(mean)

outreg2 using "$dir/results/tables/`TabATEw1_wp_fc'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity)

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)

reg share_facts_click2 i.survey   $strata $strata1 $socio $vote $fb   $reported  $behavioral i.educ $pre_treatment_vars_all if survey<4&survey>1, r
sum share_facts_click2 if e(sample)&survey==2
scalar y_contr = r(mean)

outreg2 using "$dir/results/tables/`TabATEw1_wp_fc'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr)  keep(male 1.survey 2.survey 3.survey age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey 2.survey 3.survey  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity)

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV imposed FC treatment, y_contr) keep(1.survey 2.survey 3.survey) sortvar(1.survey 2.survey 3.survey)

***********************************************************
*** Table 2, Panel C: Predicted vs. actual 
*** Table A6 
***********************************************************


cap drop diff_act_pred_want_sh_AF
gen diff_act_pred_want_sh_AF=want_share_alt_facts-pred_want_share_altfact

cap drop diff_act_pred_sh_AF
gen diff_act_pred_sh_AF=share_click2-predicted_share_altfact


local TabATE_all Table_2_panel_C 

local Tab_pred_wp Table_A6 

reg diff_act_pred_want_sh_AF i.survey_alt  if survey<4, r
sum diff_act_pred_want_sh_AF if e(sample)&survey==1
scalar y_contr = r(mean)
sum pred_want_share_altfact if e(sample)&survey==1
scalar y_pred = r(mean)
sum pred_want_share_altfact if e(sample)&survey==2
scalar y_pred2 = r(mean)
sum pred_want_share_altfact if e(sample)&survey_alt==3
scalar y_pred3 = r(mean)
sum pred_want_share_altfact if e(sample)&survey_alt==4
scalar y_pred4 = r(mean)

outreg2 using "$dir/results/tables/`Tab_pred_wp'.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(male 1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt age age_sqrd income low_educ mid_educ religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) 

reg diff_act_pred_want_sh_AF i.survey_alt $strata $strata1 if survey<4, r
sum diff_act_pred_want_sh_AF if e(sample)&survey==1
scalar y_contr = r(mean)
sum pred_want_share_altfact if e(sample)&survey==1
scalar y_pred = r(mean)
sum pred_want_share_altfact if e(sample)&survey==2
scalar y_pred2 = r(mean)
sum pred_want_share_altfact if e(sample)&survey_alt==3
scalar y_pred3 = r(mean)
sum pred_want_share_altfact if e(sample)&survey_alt==4
scalar y_pred4 = r(mean)

outreg2 using "$dir/results/tables/`Tab_pred_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(male 1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) 

reg diff_act_pred_want_sh_AF i.survey_alt   $strata $strata1 $socio $vote  $fb i.educ  if survey<4, r
sum diff_act_pred_want_sh_AF if e(sample)&survey==1
scalar y_contr = r(mean)
sum pred_want_share_altfact if e(sample)&survey==1
scalar y_pred = r(mean)
sum pred_want_share_altfact if e(sample)&survey==2
scalar y_pred2 = r(mean)
sum pred_want_share_altfact if e(sample)&survey_alt==3
scalar y_pred3 = r(mean)
sum pred_want_share_altfact if e(sample)&survey_alt==4
scalar y_pred4 = r(mean)

outreg2 using "$dir/results/tables/`Tab_pred_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  )  keep(male 1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) 

reg diff_act_pred_want_sh_AF i.survey_alt   $strata $strata1 $socio $vote $fb   $reported  $behavioral i.educ $pre_treatment_vars_all if survey<4, r
sum diff_act_pred_want_sh_AF if e(sample)&survey==1
scalar y_contr = r(mean) 
sum pred_want_share_altfact if e(sample)&survey==1
scalar y_pred = r(mean)
sum pred_want_share_altfact if e(sample)&survey==2
scalar y_pred2 = r(mean)
sum pred_want_share_altfact if e(sample)&survey_alt==3
scalar y_pred3 = r(mean)
sum pred_want_share_altfact if e(sample)&survey_alt==4
scalar y_pred4 = r(mean)

outreg2 using "$dir/results/tables/`Tab_pred_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  )  keep(male 1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) 

reg diff_act_pred_sh_AF i.survey_alt  if survey<4, r
sum diff_act_pred_sh_AF if e(sample)&survey==1
scalar y_contr = r(mean)
sum predicted_share_altfact if e(sample)&survey==1
scalar y_pred = r(mean)
sum predicted_share_altfact if e(sample)&survey==2
scalar y_pred2 = r(mean)
sum predicted_share_altfact if e(sample)&survey_alt==3
scalar y_pred3 = r(mean)
sum predicted_share_altfact if e(sample)&survey_alt==4
scalar y_pred4 = r(mean)

outreg2 using "$dir/results/tables/`Tab_pred_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(male 1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) 

reg diff_act_pred_sh_AF i.survey_alt $strata $strata1 if survey<4, r
sum diff_act_pred_sh_AF if e(sample)&survey==1
scalar y_contr = r(mean)
sum predicted_share_altfact if e(sample)&survey==1
scalar y_pred = r(mean)
sum predicted_share_altfact if e(sample)&survey==2
scalar y_pred2 = r(mean)
sum predicted_share_altfact if e(sample)&survey_alt==3
scalar y_pred3 = r(mean)
sum predicted_share_altfact if e(sample)&survey_alt==4
scalar y_pred4 = r(mean)

outreg2 using "$dir/results/tables/`Tab_pred_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(male 1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) 

reg diff_act_pred_sh_AF i.survey_alt   $strata $strata1 $socio $vote  $fb  i.educ if survey<4, r
sum diff_act_pred_sh_AF if e(sample)&survey==1
scalar y_contr = r(mean)
sum predicted_share_altfact if e(sample)&survey==1
scalar y_pred = r(mean)
sum predicted_share_altfact if e(sample)&survey==2
scalar y_pred2 = r(mean)
sum predicted_share_altfact if e(sample)&survey_alt==3
scalar y_pred3 = r(mean)
sum predicted_share_altfact if e(sample)&survey_alt==4
scalar y_pred4 = r(mean)

outreg2 using "$dir/results/tables/`Tab_pred_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  )  keep(male 1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) 

reg diff_act_pred_sh_AF i.survey_alt   $strata $strata1 $socio $vote $fb   $reported  $behavioral i.educ $pre_treatment_vars_all if survey<4, r
sum diff_act_pred_sh_AF if e(sample)&survey==1
scalar y_contr = r(mean) 
sum predicted_share_altfact if e(sample)&survey==1
scalar y_pred = r(mean)
sum predicted_share_altfact if e(sample)&survey==2
scalar y_pred2 = r(mean)
sum predicted_share_altfact if e(sample)&survey_alt==3
scalar y_pred3 = r(mean)
sum predicted_share_altfact if e(sample)&survey_alt==4
scalar y_pred4 = r(mean)

outreg2 using "$dir/results/tables/`Tab_pred_wp'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  )  keep(male 1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt age age_sqrd income low_educ mid_educ  religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt  male low_educ mid_educ age age_sqrd income religious use_FB often_share_fb log_nb_friends_fb second_mlp negative_image_UE altruism reciprocity image share_interest share_influence share_image share_reciprocity) 

outreg2 using "$dir/results/tables/`TabATE_all'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes adds(Mean DV Alt-Facts T, y_contr, Mean predicted Alt-Facts T, y_pred, Mean predicted imposed, y_pred2, Mean predicted viewer, y_pred3, Mean predicted nonviewer, y_pred4  ) keep(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) sortvar(1.survey_alt 2.survey_alt 3.survey_alt 4.survey_alt ) 

**************************************************************
** TABLE 3: share on FB vs with others
*************************************************************

tab want_share_fb want_share_others if survey<4

gen share_FB_others1=want_share_fb 
gen share_FB_others0=want_share_others

cap drop id_respondent
gen id_respondent=_n

preserve 

reshape long share_FB_others, i(id_respondent) j(FB_others)
label var FB_others "Action of Sharing on Facebook (vs. other participants)"
xtset id_respondent FB_others


gen dummy_friends_100=(nb_friends_fb>100)
gen dummy_friends_200=(nb_friends_fb>200)
gen dummy_friends_50=(nb_friends_fb>50)

gen surveyN2 =(survey==2)
label var surveyN2 "Imposed Fact-Check"
gen surveyN3 =(survey==3)
label var surveyN3 "Voluntary Fact-Check"

*** Small:

reg share_FB_others FB_others i.survey if survey<4, cl(id_respondent)
outreg2 using "$dir/results/tables/Table_3.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes  keep(FB_others 2.survey 3.survey)

reg share_FB_others FB_others i.survey c.FB_others#c.surveyN2 c.FB_others#c.surveyN3 if survey<4, r
outreg2 using "$dir/results/tables/Table_3.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes  keep(FB_others 2.survey 3.survey c.FB_others#c.surveyN2 c.FB_others#c.surveyN3)

xtreg share_FB_others FB_others i.survey if survey<4, fe cl(id_respondent)
outreg2 using "$dir/results/tables/Table_3.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes  keep(FB_others )

foreach var in dummy_friends_100 log_nb_friend often_share_fb{

xtreg share_FB_others FB_others c.FB_others#c.`var' if survey<4, fe cl(id_respondent)
outreg2 using "$dir/results/tables/Table_3.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes  keep(FB_others c.FB_others#c.surveyN2 c.FB_others#c.surveyN3 c.FB_others#c.`var')


}


restore



**************************************************************
** TABLE A8: HETEROGENEITY W.R.T. SOCIAL DESIRABILITY SCORE
*************************************************************

**** CREATE SOCIAL DESIRABILITY SCORE AND DEMEAN IT
***********************************************************************************

cap drop sds

pca   q18_3 q18_4 q20
predict sds, score

sum sds if survey<4
replace sds=sds-r(mean)

label var sds "Social Desirability Score"



***********************************************************
*** RERUN Table 2 WITH TREATMENTS INTERACTED WITH SOCIAL DESIRABILITY SCORE
***********************************************************


local TabATE_sds Table_A8 

reg want_share_fb i.survey i.survey#c.sds sds  if survey<4, r

outreg2 using "$dir/results/tables/`TabATE_sds'.xls", replace label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes  keep(i.survey i.survey#c.sds sds)   
 
reg want_share_fb i.survey i.survey#c.sds sds $strata $strata1 if survey<4, r

outreg2 using "$dir/results/tables/`TabATE_sds'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes  keep(i.survey i.survey#c.sds sds) 

reg want_share_fb i.survey i.survey#c.sds sds   $strata $strata1 $socio $vote  $fb i.educ  if survey<4, r

outreg2 using "$dir/results/tables/`TabATE_sds'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes  keep(i.survey i.survey#c.sds sds) 


reg want_share_fb i.survey i.survey#c.sds sds   $strata $strata1 $socio $vote $fb   $reported  $behavioral i.educ $pre_treatment_vars_all if survey<4, r

outreg2 using "$dir/results/tables/`TabATE_sds'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes   keep(i.survey i.survey#c.sds sds) 

reg share_click2 i.survey i.survey#c.sds sds  if survey<4, r

outreg2 using "$dir/results/tables/`TabATE_sds'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes  keep(i.survey i.survey#c.sds sds)  

reg share_click2 i.survey i.survey#c.sds sds $strata $strata1 if survey<4, r

outreg2 using "$dir/results/tables/`TabATE_sds'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes  keep(i.survey i.survey#c.sds sds) 

reg share_click2 i.survey i.survey#c.sds sds   $strata $strata1 $socio $vote  $fb  i.educ if survey<4, r

outreg2 using "$dir/results/tables/`TabATE_sds'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes   keep(i.survey i.survey#c.sds sds) 

reg share_click2 i.survey i.survey#c.sds sds   $strata $strata1 $socio $vote $fb   $reported  $behavioral i.educ $pre_treatment_vars_all if survey<4, r

outreg2 using "$dir/results/tables/`TabATE_sds'.xls", append label tex excel bdec(3) tdec(3) sdec(3) nocon nonotes   keep(i.survey i.survey#c.sds sds) 


***********************************************************************************
**** Table A2 comuns 1 and 2
***********************************************************************************

log using "$dir/results/tables/Table_A2_col_1_2", replace
sum age male married civil_partnership single  higher_education high_school daily_use_fb nb_friends_fb if survey<4
log close 

***********************************************************************************
**** FIGURES APPENDIX
***********************************************************************************

*********************************************************
***  Figure A1: Distribution of the 2 clicks variables
*********************************************************
hist share_click2 if share_click1>0&survey<4, title("Action of Sharing Alt-Facts") graphregion(color(white)) xtitle("Action of Sharing alt-facts")  bin(60)
graph save hist_2_clicks.gph, replace

hist share_facts_click2 if share_fact_click1>0&survey<4, title("Action of Sharing Fact-Check") graphregion(color(white)) xtitle("Action of Sharing fact-check")  bin(60)
graph save hist_facts_2_clicks.gph, replace

graph combine "hist_2_clicks" "hist_facts_2_clicks",   title("Sharing on Facebook among respondents,"  "who expressed the intent to share")  graphregion(color(white)) 
graph save "$dir/results/figures/Figure_A1", replace


erase hist_2_clicks.gph
erase hist_facts_2_clicks.gph

*********************************************************
***  Figure A2: selection into viewing Fact-check; variables making up propensity
*********************************************************

cap drop survey_alt_view
gen survey_alt_view=survey_alt2
label define treatment_view1   1 "Alt-Facts" 2 "Nonviewer" 3 "Viewer"
label values survey_alt_view treatment_view1


cibar  religious if survey>1, over1(survey_alt_view) barcol(sand  black ) graphopts(title("Religiosity") graphregion(color(white)) legend(cols(2)) ytitle(" "))  bargap(20)
graph save religious.gph, replace

cibar  share_influence if survey>1 , over1(survey_alt_view) barcol(sand  black  ) graphopts(title("Share in order to influence") graphregion(color(white)) legend(cols(2)) ytitle(" "))  bargap(20)
graph save influence.gph, replace

cibar  second_mlp if survey>1 , over1(survey_alt_view) barcol(sand  black  ) graphopts(title("Voted Le Pen in 2017") graphregion(color(white)) legend(cols(2)) ytitle(" "))  bargap(20)
graph save second_mlp.gph, replace

cibar  male if survey>1 , over1(survey_alt_view) barcol(sand  black  ) graphopts(title("Male") graphregion(color(white)) legend(cols(2)) ytitle(" "))  bargap(20)
graph save male.gph, replace


cibar  close_gov_eur if survey>1 , over1(survey_alt_view) barcol(sand  black  ) graphopts(title("Feel closer to European gov.") graphregion(color(white)) legend(cols(2)) ytitle(" "))  bargap(20)
graph save close_gov_eur.gph, replace

cibar  donate_blood  if survey>1 , over1(survey_alt_view) barcol(sand  black  ) graphopts(title("Donated blood") graphregion(color(white)) legend(cols(2)) ytitle(" "))  bargap(20)
graph save donate_blood.gph, replace

grc1leg "second_mlp" "close_gov_eur" "influence" "religious" "male" "donate_blood",   title("")  graphregion(color(white)) legendfrom("second_mlp")


graph save "$dir/results/figures/Figure_A2", replace
erase male.gph
erase religious.gph
erase second_mlp.gph
erase influence.gph
erase donate_blood.gph
erase close_gov_eur.gph


